## Elemental embeddings 

- `elemental_embedding_1MEGNet_layer.json` contains elemental features for 89 elements (up to Z=94, excluding Po, At, Rn, Fr, Ra) learnt from MEGNet model. The key for the dictionary is the element name and the value is a vector of length 16.
